@@ -1164,7 +1164,7 @@ terminal_screen_change_font (TerminalScreen *screen)
   terminal_screen_set_font (screen);
 
   window = terminal_screen_get_window (screen);
-  terminal_window_set_size (window, screen, TRUE);
+  terminal_window_set_size (window, screen);
 }
 
 static void
@@ -1389,7 +1389,6 @@ get_child_environment (TerminalScreen *screen,
   g_hash_table_remove (env_table, "GNOME_DESKTOP_ICON");
   
   g_hash_table_replace (env_table, g_strdup ("COLORTERM"), g_strdup (EXECUTABLE_NAME));
-  g_hash_table_replace (env_table, g_strdup ("TERM"), g_strdup ("xterm")); /* FIXME configurable later? */
   
 #ifdef GDK_WINDOWING_X11
   /* FIXME: moving the tab between windows, or the window between displays will make the next two invalid... */
@@ -2136,7 +2135,7 @@ terminal_screen_drag_data_received (GtkWidget        *widget,
           return;
 
         moving_screen = terminal_screen_container_get_screen (TERMINAL_SCREEN_CONTAINER (container));
-        g_return_if_fail (TERMINAL_IS_SCREEN (moving_screen));
+        g_warn_if_fail (TERMINAL_IS_SCREEN (moving_screen));
         if (!TERMINAL_IS_SCREEN (moving_screen))
           return;
 
